<?php
namespace Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Services\Gop01100ComparacaoVersoesOrcamentoService;

class Gop01100ComparacaoVersoesOrcamentoController extends \Zeedhi\Framework\Controller\Report {
	
	protected $birtStrategy;
	protected $environment;
	public function __construct(ReportService $reportService, $birtStrategy, Gop01100ComparacaoVersoesOrcamentoService $service,$environment) {
        $this->birtStrategy  = $birtStrategy;
        $this->reportService = $reportService;
        $this->service       = $service;
    	$this->environment = $environment;
        parent::__construct($reportService);
    }
    
    
    protected $reportMapping = array (
        'gop01100' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'CDFILIAL'       => 'P_CDFILIAL',
                'CDVERSAOGOP'    => 'P_CDVERSAOGOP',
                'NRANOVERSAOGOP' => 'P_NRANOVERSAOGOP',
                'IDPERIODOORCA'  => 'P_IDPERIODOORCA',
                'NRPERIODOORCA'  => 'P_NRPERIODOORCA',
                'NRORG'			 => 'P_NRORG'
            )
        ),
        'gop01101' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'CDFILIAL'       => 'P_CDFILIAL',
                'CDVERSAOGOP'    => 'P_CDVERSAOGOP',
                'NRANOVERSAOGOP' => 'P_NRANOVERSAOGOP',
                'IDPERIODOORCA'  => 'P_IDPERIODOORCA',
                'NRPERIODOORCA'  => 'P_NRPERIODOORCA',
                'NRORG'			 => 'P_NRORG'
            )
        )
    );
    

    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();

        $this->birtStrategy->setReportFormat($row["FORMAT"]);
        $this->birtStrategy->setReportLocale($row["LOCALE"]);
        $this->birtStrategy->setReportTimezone($row["TIMEZONE"]);
        $row['NRORG'] = $this->environment->getNrorg();
    }
    
    public function getVersoes(DTO\Request $request,DTO\Response $response) {
    	
		$currentRow  = $request->getDataSet();
		$data        = $currentRow->getRows();

		$params =  array(
            ":NRANOVERSAOGOP" => floatval($data[0]["NRANOORCAGOP"]),
            ":IDPERIODOORCA" => $data[0]["IDPERIODOORCA"],
            ":NRPERIODOORCA" => floatval($data[0]["NRPERIODOORCA"]),
            ":CDFILIAL" => $data[0]["CDFILIAL"]
        );
        
		$versoes = $this->service->getVersoes($params);
		$response->addDataSet(new DataSet("RESULT", [$versoes]));
	}
	
	public function getDataDetalhamento(DTO\Request $request,  DTO\Response $response) {
		
		$currentRow = $request->getDataSet();
		$data = $currentRow->getRows();
		if(!empty($data[0])){
			
			$params =  array(
	            ":NRANOVERSAOGOP" => floatval($data[0]["NRANOORCAGOP"]),
	            ":IDPERIODOORCA" => $data[0]["IDPERIODOORCA"],
	            ":NRPERIODOORCA" => floatval($data[0]["NRPERIODOORCA"]),
	            ":CDFILIAL" => $data[0]["CDFILIAL"]
	        );
	        
	        $paramsGetDetalhamento =  array(
	            ":P_CDFILIAL" => $data[0]["CDFILIAL"],
	            ":P_CDOPERADOR" => $data[0]["CDOPERADOR"]
	        );
	        
			$versoes = $this->service->getVersoes($params); 
			
			$stringVersoes = $this->getParametroVersoes($versoes);
			
			$result = $this->service->getDataDetalhamento($stringVersoes[0], $stringVersoes[1], $paramsGetDetalhamento);
			
			$response->addDataSet(new DataSet("RESULT", $result));
		}
	}
	
	public function getParametroVersoes($versoes){
		$stringVersoes = "";
		$stringVersoesFil = "";
		for($i = 1; $i<=$versoes; $i++){
			if(empty($stringVersoes)){
				$stringVersoes = "'Versao " . $i . "'";
				$stringVersoesFil ='NULL "' . "'Versao " . $i . "'" . '"';
			}else{
				$stringVersoes = $stringVersoes .  ", 'Versao ". $i . "'";
				$stringVersoesFil = $stringVersoesFil . ', NULL "' . "'Versao " . $i . "'" . '"';
			}
		}
		return array($stringVersoes, $stringVersoesFil);
	}
}